@@ -23,9 +23,7 @@ class LambdaApplication:
         """
         self.response = {"message": "Lambda application stopped"}
         self.context = context
-        self.event = self.process_event(event)
-
-        return self.response
+        return self.process_event(event)
 
     def process_event(self, event):
         """
@@ -34,3 +32,17 @@ class LambdaApplication:
         """
         return self.EVENT_TYPE(event)
 
+
+def overrides(base_class):
+    """
+    Decorator used to specify that a method overrides a base class method
+    """
+
+    def decorate(method):
+        """
+        Override assertion
+        """
+        assert method.__name__ in dir(base_class)
+        return method
+
+    return decorate
